# ooipy

<img src='figures/OOIPY_Logo.png' align="right" width=200>

```{include} ../README.md
:start-after: <!-- SPHINX-START -->
```
**Sections**
```{toctree}
:maxdepth: 2
getting_started
api_docs
```
